

# e-Yantra Autoeval

## Usage

- For `Sentinel Drone` theme

```sh
eyantra-autoeval evaluate --year 2022 --theme SD --task 0  # used internally
eyantra-autoeval dryrun --year 2022 --theme SD --task 0  # dryrun for them to evaluate themselves
eyantra-autoeval submit --year 2022 --theme SD --task 0  # submit to push file to server
```

